pub struct CancelIntent {
pub nonce: u64,
}Expand description
Instruction.
Fields
nonce: u64Trait Implementations
Sourceimpl BorshDeserialize for CancelIntentwhere
u64: BorshDeserialize,
impl BorshDeserialize for CancelIntentwhere
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CancelIntentwhere
u64: BorshSerialize,
impl BorshSerialize for CancelIntentwhere
u64: BorshSerialize,
Sourceimpl Discriminator for CancelIntent
impl Discriminator for CancelIntent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for CancelIntent
impl InstructionData for CancelIntent