pub struct ExecutionIntent {
pub vault: Pubkey,
pub ephemeral_authority: Pubkey,
pub executor: Pubkey,
pub nonce: u64,
pub payload_hash: [u8; 32],
pub status: u8,
pub created_at: i64,
pub cancelled_at: i64,
pub executed_at: i64,
pub bump: u8,
}Fields
vault: Pubkeyexecutor: Pubkeynonce: u64payload_hash: [u8; 32]status: u8created_at: i64cancelled_at: i64executed_at: i64bump: u8Trait Implementations
Sourceimpl AccountDeserialize for ExecutionIntent
impl AccountDeserialize for ExecutionIntent
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for ExecutionIntent
impl AccountSerialize for ExecutionIntent
Sourceimpl BorshDeserialize for ExecutionIntentwhere
Pubkey: BorshDeserialize,
u64: BorshDeserialize,
[u8; 32]: BorshDeserialize,
u8: BorshDeserialize,
i64: BorshDeserialize,
impl BorshDeserialize for ExecutionIntentwhere
Pubkey: BorshDeserialize,
u64: BorshDeserialize,
[u8; 32]: BorshDeserialize,
u8: BorshDeserialize,
i64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ExecutionIntentwhere
Pubkey: BorshSerialize,
u64: BorshSerialize,
[u8; 32]: BorshSerialize,
u8: BorshSerialize,
i64: BorshSerialize,
impl BorshSerialize for ExecutionIntentwhere
Pubkey: BorshSerialize,
u64: BorshSerialize,
[u8; 32]: BorshSerialize,
u8: BorshSerialize,
i64: BorshSerialize,
Sourceimpl Clone for ExecutionIntent
impl Clone for ExecutionIntent
Sourcefn clone(&self) -> ExecutionIntent
fn clone(&self) -> ExecutionIntent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Discriminator for ExecutionIntent
impl Discriminator for ExecutionIntent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl Space for ExecutionIntent
impl Space for ExecutionIntent
const INIT_SPACE: usize